/*
 * U-Boot JzRISC lcd controller definitions
 *
 * (C) Copyright 2001 Wolfgang Denk, DENX Software Engineering, wd@denx.de.
 * (C) Copyright Xiangfu Liu <xiangfu@sharism.cc>
 * (C) Copyright 2015 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 */

#ifndef _LCD_H_
#define _LCD_H_

/*
 * LCD controller stucture for JZSOC: JZ4740
 */
struct jz_fb_dma_descriptor {
	unsigned long fdadr;		/* Frame descriptor address register */
	unsigned long fsadr;		/* Frame source address register */
	unsigned long fidr;		/* Frame ID register */
	unsigned long ldcmd;		/* Command register */
};

/*
 * Jz LCD info
 */
struct jz_fb_info {

	unsigned long fdadr0; /* physical address of frame/palette descriptor */
	unsigned long fdadr1; /* physical address of frame descriptor */

	/* DMA descriptors */
	struct jz_fb_dma_descriptor *dmadesc_fblow;
	struct jz_fb_dma_descriptor *dmadesc_fbhigh;
	struct jz_fb_dma_descriptor *dmadesc_palette;
	unsigned long screen;		/* address of frame buffer */
	unsigned long palette;		/* address of palette memory */
	unsigned int  palette_size;
};

typedef struct vidinfo {
	unsigned short vl_col;		/* Number of columns (i.e. 640) */
	unsigned short vl_row;		/* Number of rows (i.e. 480) */
	unsigned char vl_bpix;		/* Bits per pixel, 0 = 1, 1 = 2, 2 = 4, 3 = 8 */

	struct jz_fb_info jz_fb;
} vidinfo_t;

extern vidinfo_t panel_info;

#define LCD_MONOCHROME	0
#define LCD_COLOR2	1
#define LCD_COLOR4	2
#define LCD_COLOR8	3
#define LCD_COLOR16	4
#define LCD_COLOR32	5

/* Default to 8bpp if bit depth not specified */
#ifndef LCD_BPP
#define LCD_BPP		LCD_COLOR8
#endif

#ifndef PAGE_SIZE
#define PAGE_SIZE	4096
#endif

/* Calculate nr. of bits per pixel  and nr. of colors */
#define NBITS(bit_code)		(1 << (bit_code))
#define NCOLORS(bit_code)	(1 << NBITS(bit_code))

#endif	/* _LCD_H_ */
